﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using Infragistics.Documents.Excel;
using System.Drawing;
using System.IO;
using System.Runtime.InteropServices;
using Infragistics.Windows;
using System.Windows.Markup;
using System.Xml;
using Infragistics.Controls.Charts;
using System.Reflection;


namespace DataChartToExcel
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            Panel panel = (Utilities.GetDescendantFromName(xamDataChart1, "ContentPresenter") as ContentPresenter).Content as Panel;
            Grid chartArea = panel.Children[2] as Grid;

            Workbook workbook = new Workbook();

            int width = (int)this.xamDataChart1.ActualWidth;
            int height = (int)this.xamDataChart1.ActualHeight;

            Worksheet ws1 = workbook.Worksheets.Add("Chart Sheet");

            RenderTargetBitmap bmp = new RenderTargetBitmap(width, height, 96, 96, PixelFormats.Pbgra32);
            bmp.Render(this.xamDataChart1);


            PngBitmapEncoder png = new PngBitmapEncoder();
            png.Frames.Add(BitmapFrame.Create(bmp));

            byte[] imageArray;
            using (MemoryStream ms = new MemoryStream())
            {
                png.Save(ms);
                imageArray = ms.ToArray();
            }

            MemoryStream ms1 = new MemoryStream(imageArray);
            System.Drawing.Image image = System.Drawing.Image.FromStream(ms1);

            WorksheetImage imageShape = new WorksheetImage(image);

            int cellIndex = width / 65;//65 - width in pixel of an excel cell
            int rowIndex = height / 18;//18 - height in pixels of an excel cell


            imageShape.TopLeftCornerCell = ws1.Rows[0].Cells[0]; ;
            imageShape.TopLeftCornerPosition = new PointF(0.0F, 0.0F);

            imageShape.BottomRightCornerCell = ws1.Rows[rowIndex + 1].Cells[cellIndex + 1]; ;
            imageShape.BottomRightCornerPosition = new PointF(100.0F, 100.0F);

            ws1.Shapes.Add(imageShape);

            workbook.Save("chart.xls");
            Process.Start("chart.xls");

        }

      

    }

    public class GridData
    {
        public BitmapImage Data { get; set; }
    }
    public class DataColl : ObservableCollection<Data>
    {
        public DataColl()
        {
            Random r = new Random();
            for (int i = 0; i < 20; i++)
            {
                this.Add(new Data
                {
                    Label = "Item " + i,
                    Value = r.Next(10, 20),
                    Value1 = r.Next(20, 40),
                    Value2 = r.Next(10, 50)
                });
            }
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private int val;
        private int val1;
        private int val2;
        private string label;

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Value
        {
            get { return val; }
            set
            {
                val = value;
                PropChanged("Value");
            }
        }

        public int Value1
        {
            get { return val1; }
            set
            {
                val1 = value;
                PropChanged("Value1");
            }
        }

        public int Value2
        {
            get { return val2; }
            set
            {
                val2 = value;
                PropChanged("Value2");
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Label = "Item " + i,
                    Value = r.Next(rangeStart, rangeEnd),
                    Value1 = r.Next(rangeStart, rangeEnd),
                    Value2 = r.Next(rangeStart, rangeEnd)
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
